@@ -66,3 +66,27 @@ def test_google_form_csv():
     ]
 
     assert actual == expected
+
+
+def test_google_form_csv_weighted():
+    actual = pystv.parse_google_form_csv(PATH / "transform_weighted_testdata.csv")
+
+    metadata = RM(
+        "What is your favorite season?", 1, ["Spring", "Summer", "Autumn", "Winter"]
+    )
+    expected = [
+        RaceInfo(
+            metadata,
+            [
+                [1, 0, 0, 0],
+                [1, 3, 2, 4],
+                [2, 0, 0, 0],
+                [2, 3, 4, 1],
+                [3, 1, 4, 2],
+                [3, 2, 4, 1],
+            ],
+            [3, 1, 2, 3, 4, 3],
+        )
+    ]
+
+    assert actual == expected
